set memory 500m

use "SourceSalesTaxData\al.dta"

append using "SourceSalesTaxData\az.dta"

append using "SourceSalesTaxData\ar.dta"

append using "SourceSalesTaxData\ca.dta"

append using "SourceSalesTaxData\co.dta"

append using "SourceSalesTaxData\fl.dta"

append using "SourceSalesTaxData\ga.dta"

append using "SourceSalesTaxData\ia.dta"

append using "SourceSalesTaxData\id.dta"

append using "SourceSalesTaxData\il.dta"

append using "SourceSalesTaxData\ks.dta"

append using "SourceSalesTaxData\ME.dta"

append using "SourceSalesTaxData\MN.dta"

append using "SourceSalesTaxData\MO.dta"

append using "SourceSalesTaxData\NE.dta"

append using "SourceSalesTaxData\NC.dta"

append using "SourceSalesTaxData\ok.dta"

append using "SourceSalesTaxData\sc.dta"

append using "SourceSalesTaxData\sd.dta"

append using "SourceSalesTaxData\TN.dta"

append using "SourceSalesTaxData\TX.dta"

append using "SourceSalesTaxData\ut.dta"

append using "SourceSalesTaxData\vt.dta"

append using "SourceSalesTaxData\VA.dta"

append using "SourceSalesTaxData\WA.dta"

append using "SourceSalesTaxData\wi.dta"

replace state=lower(state)
replace county=lower(county)

*fix mising data
replace cyq1=. if cyq1==0
replace nyq1=. if nyq1==0
replace cyq3=. if cyq3==0

*in illinois, figures are tax receipts. to get taxable sales, need to multiple by 100
replace cyq1=cyq1*100 if state=="il"
replace nyq1=nyq1*100 if state=="il"
replace cyq3=cyq3*100 if state=="il"

***
*PROBLEM DATA: South Dakota data prior to 1996 are not comparable to prior data. Eliminate earlier data.
***
drop if year<1996 & state=="sd"

*******************************************
*Merge in additional data (e.g., elections)
*******************************************

*Temporarily save vermont and maine data for later (those places don't have counties)
*Get 2000 election results for those areas
*
preserve
keep if fips_st==23 | fips_st==50
joinby fipsindx using "data\fipsindx_to_00vote_maine_esa_vermont_town.dta", unmatched(master)
rename d2p00 dempres2p_00
drop _merge
save data\mainevermont.dta, replace
restore

*Process the remaining states
drop if fips_st==23 | fips_st==50
joinby fipsindx using "data\fipsindx_to_00vote_nomainevermont.dta"
joinby fipsindx using "data\fipsindx_to_80vote.dta"
joinby fipsindx using "data\fipsindx_to_avg8088vote.dta"
joinby fipsindx using "data\fipsindx_to_avg8000vote.dta"
joinby fipsindx using "data\fipsindx_to_avg9204vote.dta"
rename d2p00 dempres2p_00
rename dprop2p80 dempres2p_80

label var dempres2p_00 "Dem. Prop. 2-party Pres. vote 2000"
label var dempres2p_80 "Dem. Prop. 2-party Pres. vote 1980"
label var dempres2pavg_8088 "Dem. Prop. 2-party Pres. vote 1980-1988"
label var dempres2pavg_8000 "Dem. Prop. 2-party Pres. vote 1980-2000"
label var dempres2pavg_9204 "Dem. Prop. 2-party Pres. vote 1992-2004"

****
*Merge in data on observed pci per county/unit. (Note that we lose all sub-county obs here)
****
sort fipsindx
joinby fipsindx using data\fipsindx_to_bea_pci.dta, unmatched(master)
tab state if _merge==1
drop _merge

****
*Merge in data on county demographics. (Note that we lose all sub-county obs here)
****
*miami dade cty
replace fipsindx=12025 if fipsindx==12086
sort fipsindx
joinby fipsindx using data\countydemographics.dta, unmatched(both)
replace fipsindx=12086 if fipsindx==12025
gen logpop=ln(pop2000)
tab state if _merge==1
drop if _merge==2
drop _merge

***
*Merge in county-level education figures
****
sort fipsindx
joinby fipsindx using data\educationfromusacounties.dta, unmatched(master)
drop _merge
label var prop25andovercollegeplus "Prop. Pop. Age 25+ w/ BA or more 2000"

***
*Merge in county-level religion figures
****
*miami dade cty
replace fipsindx=12025 if fipsindx==12086
sort fipsindx
joinby fipsindx using data\countyreligionestimates.dta, unmatched(master)
replace fipsindx=12086 if fipsindx==12025
drop _merge

****
*Merge in data on county economies (Note that we lose all sub-county obs here)
****
sort fipsindx
joinby fipsindx using data\countyclass.dta, unmatched(both)
tab state if _merge==1
drop if _merge==2
drop _merge

****
*Merge in data on indian reservations. (Note that we don't get rid of reservations in Maine or Vermont, since those aren't county data)
****
sort fipsindx
joinby fipsindx using data\fipsindx_to_indianreservations.dta, unmatched(master)
drop _merge

****
*Merge in STATE partisanship data
****
sort st
joinby st using data\state_partisanship_byst.dta, unmatched(master)
drop _merge

*Go back and get Maine and Vermont data
*
append using data\mainevermont.dta
!erase data\mainevermont.dta

order fipsindx fips_st fips_substate fipslevel state county year cyq1 cyq3 nyq1 dempres2pavg_8088 dempres2pavg_8000 dempres2p_80 dempres2p_00

*we also would like next year's 3rd quarter in the data. For that, we need to properly sort the data;
gen nyq3=.
sort fipsindx year
replace nyq3=cyq3[_n+1] if fipsindx==fipsindx[_n+1] & year+1==year[_n+1]

*****
*Now generate dependent variables, etc.
*****

*dependent variables
gen logchg1qfrom3q=log(nyq1/cyq3)
gen logchg3qfrom1q=log(cyq3/cyq1)
gen logchg3qfrom3q=log(nyq3/cyq3)

****
*Calculate lagged observed 1q from 3q changes
***

*logged
sort fipsindx year
gen year1lagchange=.
gen year2lagchange=.
gen year3lagchange=.
replace year1lagchange=logchg1qfrom3q[_n-1] if fipsindx[_n-1] == fipsindx & year[_n-1] == year-1
replace year2lagchange=logchg1qfrom3q[_n-2] if fipsindx[_n-2] == fipsindx & year[_n-2] == year-2
replace year3lagchange=logchg1qfrom3q[_n-3] if fipsindx[_n-3] == fipsindx & year[_n-3] == year-3
*last 3 years
egen validlagobs=robs(year1lagchange year2lagchange year3lagchange)
egen avg_3yr_log3qto1q=rmean(year1lagchange year2lagchange year3lagchange)
replace avg_3yr_log3qto1q=. if validlagobs~=3
drop year1lagchange year2lagchange year3lagchange validlagobs

****
*Calculate lagged observed 3q from 1q changes
***

*logged
sort fipsindx year
gen year1lagchange=.
gen year2lagchange=.
gen year3lagchange=.
replace year1lagchange=logchg3qfrom1q[_n-1] if fipsindx[_n-1] == fipsindx & year[_n-1] == year-1
replace year2lagchange=logchg3qfrom1q[_n-2] if fipsindx[_n-2] == fipsindx & year[_n-2] == year-2
replace year3lagchange=logchg3qfrom1q[_n-3] if fipsindx[_n-3] == fipsindx & year[_n-3] == year-3

*last 3 years
egen validlagobs=robs(year1lagchange year2lagchange year3lagchange)
egen avg_3yr_log1qto3q=rmean(year1lagchange year2lagchange year3lagchange)
replace avg_3yr_log1qto3q=. if validlagobs~=3
drop year1lagchange year2lagchange year3lagchange validlagobs

****
*Calculate lagged observed 3q from 3q changes, note that we exclude the 1q from the previous year because it is included in current year measure
***

*logged
sort fipsindx year
gen year2lagchange=.
gen year3lagchange=.
replace year2lagchange=logchg3qfrom3q[_n-2] if fipsindx[_n-2] == fipsindx & year[_n-2] == year-2
replace year3lagchange=logchg3qfrom3q[_n-3] if fipsindx[_n-3] == fipsindx & year[_n-3] == year-3

*prior 2 years (excluding observation overlapping current year)
egen validlagobs=robs(year2lagchange year3lagchange)
egen avg_3yr_log3qto3q=rmean(year2lagchange year3lagchange)
replace avg_3yr_log3qto3q=. if validlagobs~=2
drop year2lagchange year3lagchange validlagobs

***
*Label variables
***

label var logchg1qfrom3q "Log(Next year's 1q sales/Current year's 3q sales)"
label var logchg3qfrom1q "Log(Current year's 3q sales/Current year's 1q sales)"
label var logchg3qfrom3q "Log(Next year's 3q sales/Current year's 3q sales)"

label var avg_3yr_log3qto1q "Prev. 3 year avg. change in D.V."
label var avg_3yr_log1qto3q "Prev. 3 year avg. change in D.V."
label var avg_3yr_log3qto3q "Prior 2 year's avg. change in D.V."

*Save completed dataset

save "data\consolidated_salestaxandelectiondata.dta", replace
